<?php
include_once("appconfig.php");


class Tabels {                               
    const AthleticNames = "_tbl_masters_miscellaneous_athleticnames";
    const HobbieNames = "_tbl_masters_miscellaneous_hobbienames";
    const SportsNames = "_tbl_masters_miscellaneous_sportsnames";
    
    const BoardOfEducations = "_tbl_masters_appcommon_boardofeducations";
    const QualificationNames = "_tbl_masters_appcommon_qualificationnames";
    const StaffTypes = "_tbl_masters_appcommon_stafftypes";
    const StudentCategories = "_tbl_masters_appcommon_studentcategories";
    const StudentStatus = "_tbl_masters_appcommon_studentstatus";
    const UniversityNames = "_tbl_masters_appcommon_universitynames";
    const HscGroupNames = "_tbl_masters_appcommon_hscgroupnames";
    
    const Designations = "_tbl_masters_appcommon_designations";
    const BloodGroups = "_tbl_masters_common_bloodgroups";
    const CasteNames = "_tbl_masters_common_castenames";
    const CommunityNames = "_tbl_masters_common_communitynames";
    const CountryNames = "_tbl_masters_common_countrynames";
    const Languages = "_tbl_masters_common_languages";
    const MaritalStatus = "_tbl_masters_common_maritalstatus";
    const Nationalities = "_tbl_masters_common_nationalities";
    const ReligionNames = "_tbl_masters_common_religionnames";
    
    const Classes = "_tbl_masters_academy_classes";
    const CourseTypes = "_tbl_masters_academy_coursetypes";
    const Departments = "_tbl_masters_academy_departments";
    const Divisions = "_tbl_masters_academy_divisions";
    const Semesters = "_tbl_masters_academy_semesters";
    
    const IncomeRanges = "_tbl_masters_common_incomeranges";
    const AdmissionQuotas = "_tbl_masters_common_admissionquotas";
    const ApplicantTypes = "_tbl_masters_common_applicanttypes";
    const DcoumentTypes = "_tbl_masters_common_documenttypes";
    const AcademicYears= "_tbl_masters_common_academicyears";
    const SchoolNames= "_tbl_masters_appcommon_schoolnames";
    const CollegeNames= "_tbl_masters_appcommon_collegenames";
    const InstitutionNames= "_tbl_masters_appcommon_institutionnames";
    const Occupations= "_tbl_masters_appcommon_occupations";
    
    const Grades= "_tbl_masters_academy_grades";
    const Examinations= "_tbl_masters_academy_examinations";
    const CurrencyNames= "_tbl_masters_common_currencynames";

    const StateNames= "_tbl_masters_common_statenames";
    const DistrictNames= "_tbl_masters_common_districtnames";
    const SchemeNames= "_tbl_masters_appcommon_schemeNames";
    const InstitutionTypes= "_tbl_masters_common_institutiontypes";
    const SubjectNames= "_tbl_masters_academy_subjectnames";
    
    const CourseNames= "_tbl_masters_academy_coursenames";
    const Gender= "_tbl_masters_common_gender";
    const Batches= "_tbl_masters_academy_batches";
}

function hideMobilNumber($number) {
    $number = array_map('intval', str_split(trim($number)));
     return $number[0].$number[1]."X"."X"."X"."X"."X".$number[7].$number[8].$number[9];
}
function isLogged() {
    if (isset($_SESSION['User']['IsActive'])) {
        return true;
    }
    return false;
}

 
$metohd['login']=array("classfile"=>"webservices/class.Login.php",
                      "classname"=>"Login",
                      "dol"=>"doLogin");
                       
                      
$metohd['mmal']=array("classfile"=>"webservices/class.AthleticNames.php",
                      "classname"=>"AthleticNames",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");

$metohd['mmhl']=array("classfile"=>"webservices/class.HobbieNames.php",
                      "classname"=>"HobbieNames",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");   

$metohd['mmsl']=array("classfile"=>"webservices/class.SportsNames.php",
                      "classname"=>"SportsNames",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
                      
                      
$metohd['macbel']=array("classfile"=>"webservices/class.BoardOfEducations.php",
                      "classname"=>"BoardOfEducations",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['macql']=array("classfile"=>"webservices/class.QualificationNames.php",
                      "classname"=>"QualificationNames",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['macstl']=array("classfile"=>"webservices/class.StaffTypes.php",
                      "classname"=>"StaffTypes",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
                      
$metohd['macscl']=array("classfile"=>"webservices/class.StudentCategories.php",
                      "classname"=>"StudentCategories",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['macssl']=array("classfile"=>"webservices/class.StudentStatus.php",
                      "classname"=>"StudentStatus",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['macunl']=array("classfile"=>"webservices/class.UniversityNames.php",
                      "classname"=>"UniversityNames",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['machgnl']=array("classfile"=>"webservices/class.HscGroupNames.php",
                      "classname"=>"HscGroupNames",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",        
                      "g"=>"getData",
                      "r"=>"remove");
                      
$metohd['macdel']=array("classfile"=>"webservices/class.Designations.php",
                      "classname"=>"Designations",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['mcbgl']=array("classfile"=>"webservices/class.BloodGroups.php",
                      "classname"=>"BloodGroups",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['mccnl']=array("classfile"=>"webservices/class.CasteNames.php",
                      "classname"=>"CasteNames",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['mccl']=array("classfile"=>"webservices/class.CommunityNames.php",
                      "classname"=>"CommunityNames",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['mccol']=array("classfile"=>"webservices/class.CountryNames.php",
                      "classname"=>"CountryNames",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "lac"=>"listActive",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['mcll']=array("classfile"=>"webservices/class.Languages.php",
                      "classname"=>"Languages",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['mcmsl']=array("classfile"=>"webservices/class.MaritalStatus.php",
                      "classname"=>"MaritalStatus",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['mcnl']=array("classfile"=>"webservices/class.Nationalities.php",
                      "classname"=>"Nationalities",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");    


$metohd['mcrnl']=array("classfile"=>"webservices/class.ReligionNames.php",
                      "classname"=>"ReligionNames",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove"); 
                      
                      
$metohd['mcirl']=array("classfile"=>"webservices/class.IncomeRanges.php",
                      "classname"=>"IncomeRanges",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove"); 
                      
$metohd['mcaql']=array("classfile"=>"webservices/class.AdmissionQuotas.php",
                      "classname"=>"AdmissionQuotas",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['mcatl']=array("classfile"=>"webservices/class.ApplicantTypes.php",
                      "classname"=>"ApplicantTypes",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['mactl']=array("classfile"=>"webservices/class.CourseTypes.php",
                      "classname"=>"CourseTypes",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "lac"=>"listActive", /*list all active*/
                      "g"=>"getData",
                      "r"=>"remove");
                            
$metohd['madl']=array("classfile"=>"webservices/class.Departments.php",
                      "classname"=>"Departments",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "lac"=>"listAllActive",
                      "g"=>"getData",
                      "r"=>"remove");

$metohd['madvl']=array("classfile"=>"webservices/class.Divisions.php",
                      "classname"=>"Divisions",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");

$metohd['macll']=array("classfile"=>"webservices/class.Classes.php",
                      "classname"=>"Classes",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");

$metohd['masl']=array("classfile"=>"webservices/class.Semesters.php",
                      "classname"=>"Semesters",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
                      
 
$metohd['mcdtl']=array("classfile"=>"webservices/class.DocumentTypes.php",
                      "classname"=>"DocumentTypes",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");

$metohd['mcotl']=array("classfile"=>"webservices/class.Occupations.php",
                      "classname"=>"Occupations",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");

$metohd['magl']=array("classfile"=>"webservices/class.Grades.php",
                      "classname"=>"Grades",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");

$metohd['mael']=array("classfile"=>"webservices/class.Examinations.php",
                      "classname"=>"Examinations",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
                      
                      
$metohd['maayl']=array("classfile"=>"webservices/class.AcademicYears.php",
                      "classname"=>"AcademicYears",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");

$metohd['masnl']=array("classfile"=>"webservices/class.SchoolNames.php",
                      "classname"=>"SchoolNames",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");

$metohd['macoll']=array("classfile"=>"webservices/class.CollegeNames.php",  
                      "classname"=>"CollegeNames",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");

$metohd['mainl']=array("classfile"=>"webservices/class.InstitutionNames.php",
                      "classname"=>"InstitutionNames",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['mccunl']=array("classfile"=>"webservices/class.CurrencyNames.php",
                      "classname"=>"CurrencyNames",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['macsl']=array("classfile"=>"webservices/class.SchemeNames.php",
                      "classname"=>"SchemeNames",      
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['mcitl']=array("classfile"=>"webservices/class.InstitutionTypes.php",
                      "classname"=>"InstitutionTypes",      
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['masul']=array("classfile"=>"webservices/class.SubjectNames.php",
                      "classname"=>"SubjectNames",      
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");                      
                      
$metohd['mcsnl']=array("classfile"=>"webservices/class.StateNames.php",
                      "classname"=>"StateNames",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "labc"=>"listActiveByCountryID", /*list active by country id*/
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['mcdnl']=array("classfile"=>"webservices/class.DistrictNames.php",
                      "classname"=>"DistrictNames",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "labd"=>"listActive", /*list active by state id*/
                      "g"=>"getData",
                      "r"=>"remove");
                      
$metohd['macoul']=array("classfile"=>"webservices/class.CourseNames.php",
                      "classname"=>"CourseNames",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['mcgndrl']=array("classfile"=>"webservices/class.Gender.php",
                      "classname"=>"Gender",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
$metohd['mabl']=array("classfile"=>"webservices/class.Batches.php",
                      "classname"=>"Batches",
                      "a"=>"addNew",
                      "u"=>"doUpdate",
                      "l"=>"listAll",
                      "g"=>"getData",
                      "r"=>"remove");
                      
                      
                      
                       
                      

function getDifferenceBetweenTwoDates($fromDate,$toDate,&$years,&$months,&$days) {

    // Declare and define two dates
    $date1 = strtotime($fromDate); 
    $date2 = strtotime($toDate); 
 
    // Formulate the Difference between two dates
    $diff = abs($date2 - $date1); 
 
    // To get the year divide the resultant date into
    // total seconds in a year (365*60*60*24)
    $years = floor($diff / (365*60*60*24)); 
    $months = floor(($diff - $years * 365*60*60*24) / (30*60*60*24)); 
    $days = floor(($diff - $years * 365*60*60*24 - $months*30*60*60*24)/ (60*60*24));
    $hours = floor(($diff - $years * 365*60*60*24          - $months*30*60*60*24 - $days*60*60*24)                                      / (60*60)); 
    $minutes = floor(($diff - $years * 365*60*60*24            - $months*30*60*60*24 - $days*60*60*24                             - $hours*60*60)/ 60); 
    $seconds = floor(($diff - $years * 365*60*60*24            - $months*30*60*60*24 - $days*60*60*24                   - $hours*60*60 - $minutes*60)); 
}                
 

if (isset($metohd[$_GET['method']])) {
    include_once($metohd[$_GET['method']]['classfile'])     ;
    $class  = $metohd[$_GET['method']]['classname'];
    $action = $metohd[$_GET['method']][$_GET['action']];
    $ws = new $class();
    echo $ws->$action(); 
} else {
   echo "error";
}
?>